@@ -43,7 +43,6 @@ class Image:
         metadata=None,
         transpose=False,
         hot_pixel_threshold=200000,
-        pixel_maximum=1000000,
         pixel_minimum=0
     ):
         """
@@ -57,9 +56,6 @@ class Image:
         img.close()
         if transpose:
             array = array.T
-        self.skip = False
-        if (array > pixel_maximum).any():
-            self.skip = True
         # Remove hot pixels
         array = _find_hot_pixels(array, threshold=hot_pixel_threshold)
         array[np.where(array < pixel_minimum)] = 0
